ByteSteps class abstract final

Factory namespace for byte-oriented flow steps.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

constantTimeEquals(Uint8List expected) CryptoStep<Uint8List, bool>
Compares the current bytes with a defensively retained expected value.