CryptoCancellationToken class final

Mutable cooperative cancellation signal for one or more flow executions.

Cancellation is permanent for this token. Create a new token for unrelated work that must remain independently cancellable.

Constructors

CryptoCancellationToken()

Properties

hashCode int
The hash code for this object.
no setterinherited
isCancelled bool
Whether cancellation has been requested.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → void
Requests cancellation at the next flow execution boundary.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited