CryptoFlowCancelledException class final
Thrown when cooperative flow cancellation is observed at a boundary.
- Inheritance
-
- Object
- CryptoException
- CryptoFlowCancelledException
Constructors
- CryptoFlowCancelledException()
- Creates the stable cooperative-cancellation failure.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited