EncodingSteps class abstract final

Factory namespace for strict text/byte encoding flow steps.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

base64Decode() CryptoStep<String, Uint8List>
Decodes strict canonical standard Base64 text to bytes.
base64Encode() CryptoStep<Uint8List, String>
Encodes bytes as canonical padded standard Base64.
hexDecode() CryptoStep<String, Uint8List>
Decodes strict hexadecimal text to bytes.
hexEncode() CryptoStep<Uint8List, String>
Encodes bytes as canonical lowercase hexadecimal.