Strict byte encoding and comparison utilities.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
constantTimeEquals(
Uint8List left, Uint8List right) → Future< bool> - Compares equal-length inputs using Rust's constant-time equality primitive.
-
decodeBase64(
String value) → Uint8List - Decodes canonical padded RFC 4648 standard Base64.
-
decodeHex(
String value) → Uint8List - Decodes even-length hexadecimal without prefixes or whitespace.
-
encodeBase64(
Uint8List value) → String - Encodes bytes as canonical padded RFC 4648 standard Base64.
-
encodeHex(
Uint8List value) → String - Encodes bytes as lowercase hexadecimal without a prefix.